@@ -1,7 +1,7 @@
 def get_areas(clusters, points):
     num_points = len(points)
     areas_to_points = dict()
-    for i in range(0,num_points):
+    for i in range(num_points):
         area = int(clusters[i])
         if area in areas_to_points:
             areas_to_points[area].append(points[i])
